# API Reference

## Extraction

::: infoextract_cidoc.extraction.LangStructExtractor

::: infoextract_cidoc.extraction.resolve_extraction

::: infoextract_cidoc.extraction.map_to_crm_entities

::: infoextract_cidoc.extraction.models.ExtractionResult

::: infoextract_cidoc.extraction.models.ExtractedEntity

::: infoextract_cidoc.extraction.lite_schema.LiteExtractionResult

## Models

::: infoextract_cidoc.models.base.CRMEntity

::: infoextract_cidoc.models.base.CRMRelation

## I/O

::: infoextract_cidoc.io.to_markdown.to_markdown

::: infoextract_cidoc.io.to_cypher.generate_cypher_script

::: infoextract_cidoc.io.to_networkx.to_networkx_graph
